@@ -139,9 +139,9 @@ def set_threads_per_process(args):
         f"Total threads on machine: {total_threads}. Requested threads for segmentation: {required_threads}"
     )
     if total_threads < required_threads:
-        args.threads_per_process = floor(total_threads / args.n_processes)
+        # args.threads_per_process = floor(total_threads / args.n_processes)
         logger.warning(
-            "Desired threads (n_processes * threads_per_process) > total threads on device ({}>{}). Limiting threads per worker to {}. If performance drops, consider reducing the number of workers and upping threads to match.",
+            "Desired threads (n_processes * threads_per_process) > total threads on device ({}>{}). Monitor and change either the number of workers or threads if performance drops.",
             required_threads,
             total_threads,
             args.threads_per_process,
