@@ -39,29 +39,34 @@ class Nifti:
             raise SimpleITKReadError()
         self.spacing = self.img.GetSpacing()
         self.shape = self.img.GetSize()
-        if (self.parent / "metadata.json").exists():
-            logger.trace(f"{self.parent / 'metadata.json'} found. Loading metadata.")
-            with (self.parent / "metadata.json").open() as f:
-                self.metadata: dict = json.load(f)
-            if self.metadata.get("series_uid") is None:
-                self.metadata["series_uid"] = str(uuid4())
-                self._write_metadata()
+        try:
+            if (self.parent / "metadata.json").exists():
+                logger.trace(f"{self.parent / 'metadata.json'} found. Loading metadata.")
+                with (self.parent / "metadata.json").open() as f:
+                    self.metadata: dict = json.load(f)
+                if self.metadata.get("series_uid") is None:
+                    self.metadata["series_uid"] = str(uuid4())
+                    self._write_metadata()
 
-        elif (self.parent / "header_info.json").exists():
-            logger.trace(
-                f"Old format metadata {self.parent / 'header_info.json'} found. Loading metadata."
-            )
-            with (self.parent / "header_info.json").open() as f:
-                self.metadata: dict = json.load(f)
-            logger.trace("Updating metadata in Nifti.__init__")
-            self.update_metadata_file()
-        else:
-            logger.debug(
-                f"No metadata.json or header_info.json file found next to {nifti_path}. Setting metadata['series_uid'] to a file with a generated uuid."
-            )
+            elif (self.parent / "header_info.json").exists():
+                logger.trace(
+                    f"Old format metadata {self.parent / 'header_info.json'} found. Loading metadata."
+                )
+                with (self.parent / "header_info.json").open() as f:
+                    self.metadata: dict = json.load(f)
+                logger.trace("Updating metadata in Nifti.__init__")
+                self.update_metadata_file()
+            else:
+                logger.debug(
+                    f"No metadata.json or header_info.json file found next to {nifti_path}. Setting metadata['series_uid'] to a file with a generated uuid."
+                )
+                self.metadata: dict = {"series_uid": str(uuid4())}
+                self._write_metadata()
+        except json.JSONDecodeError as e:
+            logger.warning('Existing metadata cannot be loaded from json. Creating a generated Series UID')
             self.metadata: dict = {"series_uid": str(uuid4())}
             self._write_metadata()
-
+            
     def update_metadata_file(self) -> None:
         dicoms = list(self.parent.glob("*.dcm"))
         if not dicoms:
