@@ -42,13 +42,13 @@ class Analyzer:
     }
     # Segmentations needed for specific tasks in order of preference
     task_map = {
-        "vol_int": ["999", "total"],
-        "contrast": ["999", "total"],
-        "vertebrae": ["999", "total"],
-        "aorta": ["999", "total"],
+        "vol_int": ["998", "999", "total"],
+        "contrast": ["998", "999", "total"],
+        "vertebrae": ["998", "999", "total"],
+        "aorta": ["998", "999", "total"],
         "tissues": ["485", "481", "tissues"],
         "body": ["299", "300", "body"],
-        "iliac": ["999", "total"],
+        "iliac": ["998", "999", "total"],
     }
 
     def __init__(
@@ -175,7 +175,7 @@ class Analyzer:
             except Exception as e:
                 logger.error(f"Error calculating {task} statistics: {e}")
 
-    def run(self, batch_insert_size: int = 20) -> None:
+    def run(self, batch_insert_size: int = 50) -> None:
         """Run the analysis on the provided NiFTi files.
         :param niftis: Path to a nifti file with mircat-v2 segmentations or a text file with a list of multiple mircat-v2 nifti files.
         """
@@ -198,7 +198,7 @@ class Analyzer:
                         continue
 
                     logger.success(
-                        f"Stats Completed: [{i}/{self.total_niftis}] ({i/self.total_niftis:.2%})."
+                        f"Stats Completed: [{i}/{self.total_niftis}] ({i/self.total_niftis:.2%}) - {nifti.path}"
                     )
                     if self.dbase_insert:
                         for key, list_data in nifti.db_stats.items():
